what.cli API documentation

# what.cli

The `what` CLI tool.

## what.cli.model

A list of pre-trained models.

## what.cli.attack

A list of adversarial attacks.

## what.cli.example

A list of examples.

View Source

     1r'''
     2
     3The `what` CLI tool.
     4
     5## what.cli.model
     6
     7A list of pre-trained models.
     8
     9## what.cli.attack
    10
    11A list of adversarial attacks.
    12
    13## what.cli.example
    14
    15A list of examples.
    16
    17'''
    18
    19__all__ = []